@@ -11,6 +11,7 @@ from wiki.core import article_markdown, permissions
 from wiki.core import compat
 from wiki import managers
 from wiki.models import BaseRevisionMixin
+from wiki.models import Article
 
 from mptt.models import MPTTModel
 
@@ -18,6 +19,8 @@ from mptt.models import MPTTModel
 class Section(models.Model):
     objects = managers.PermissionManager()
 
+    article = models.OneToOneField(Article, default=None, null=True, related_name='section')
+
     current_revision = models.OneToOneField(
         'SectionRevision',
         verbose_name=_(u'current revision'),
@@ -198,9 +201,16 @@ class SectionRevision(BaseRevisionMixin, models.Model):
         unique_together = ('section', 'revision_number')
 
 
-#class SectionTree(MPTTModel):
-#    parent = TreeForeignKey('self', null=True, blank=True, related_name='children')
-#
-#    class MPTTMeta:
-#        order_insertion_by = ['name']
+class SectionNode(MPTTModel):
+    parent = TreeForeignKey('self', null=True, blank=True, related_name='children')
+    section = models.ForeignKey(Section, related_name='node')
 
+    slug = models.SlugField(verbose_name=_(u'slug'), null=True, blank=True,
+                            max_length=50)
+
+    class MPTTMeta:
+        pass
+
+    class Meta:
+        unique_together = ('parent', 'slug')
+        app_label = settings.APP_LABEL
